pub struct Counters {
pub enabled: bool,
pub step_time: Timer,
pub custom: Timer,
pub stages: StagesCounters,
pub cd: CollisionDetectionCounters,
pub solver: SolverCounters,
pub ccd: CCDCounters,
}Expand description
Aggregation of all the performances counters tracked by rapier.
Fields
enabled: boolWhether this counter is enabled or not.
step_time: TimerTimer for a whole timestep.
custom: TimerTimer used for debugging.
stages: StagesCountersCounters of every stage of one time step.
cd: CollisionDetectionCountersCounters of the collision-detection stage.
solver: SolverCountersCounters of the constraints resolution and force computation stage.
ccd: CCDCountersCounters for the CCD resolution stage.
Implementations
Sourceimpl Counters
impl Counters
Sourcepub fn step_started(&mut self)
pub fn step_started(&mut self)
Notify that the time-step has started.
Sourcepub fn step_completed(&mut self)
pub fn step_completed(&mut self)
Notify that the time-step has finished.
Sourcepub fn step_time_ms(&self) -> f64
pub fn step_time_ms(&self) -> f64
Total time spent for one of the physics engine, in milliseconds.
Sourcepub fn custom_started(&mut self)
pub fn custom_started(&mut self)
Notify that the custom operation has started.
Sourcepub fn custom_completed(&mut self)
pub fn custom_completed(&mut self)
Notify that the custom operation has finished.
Sourcepub fn custom_time(&self) -> Duration
pub fn custom_time(&self) -> Duration
Total time of a custom event.
Sourcepub fn custom_time_ms(&self) -> f64
pub fn custom_time_ms(&self) -> f64
Total time of a custom event, in milliseconds.
Sourcepub fn set_nconstraints(&mut self, n: usize)
pub fn set_nconstraints(&mut self, n: usize)
Set the number of constraints generated.
Sourcepub fn set_ncontacts(&mut self, n: usize)
pub fn set_ncontacts(&mut self, n: usize)
Set the number of contacts generated.
Sourcepub fn set_ncontact_pairs(&mut self, n: usize)
pub fn set_ncontact_pairs(&mut self, n: usize)
Set the number of contact pairs generated.
Sourceimpl Counters
impl Counters
Sourcepub fn update_started(&mut self)
pub fn update_started(&mut self)
Start this timer.
Sourcepub fn update_completed(&mut self)
pub fn update_completed(&mut self)
Stop this timer.
Sourcepub fn update_time_ms(&self) -> f64
pub fn update_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn collision_detection_started(&mut self)
pub fn collision_detection_started(&mut self)
Start this timer.
Sourcepub fn collision_detection_completed(&mut self)
pub fn collision_detection_completed(&mut self)
Stop this timer.
Sourcepub fn collision_detection_time_ms(&self) -> f64
pub fn collision_detection_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn island_construction_started(&mut self)
pub fn island_construction_started(&mut self)
Start this timer.
Sourcepub fn island_construction_completed(&mut self)
pub fn island_construction_completed(&mut self)
Stop this timer.
Sourcepub fn island_construction_time_ms(&self) -> f64
pub fn island_construction_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn solver_started(&mut self)
pub fn solver_started(&mut self)
Start this timer.
Sourcepub fn solver_completed(&mut self)
pub fn solver_completed(&mut self)
Stop this timer.
Sourcepub fn solver_time_ms(&self) -> f64
pub fn solver_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn ccd_started(&mut self)
pub fn ccd_started(&mut self)
Start this timer.
Sourcepub fn ccd_completed(&mut self)
pub fn ccd_completed(&mut self)
Stop this timer.
Sourcepub fn ccd_time_ms(&self) -> f64
pub fn ccd_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn assembly_started(&mut self)
pub fn assembly_started(&mut self)
Start this timer.
Sourcepub fn assembly_completed(&mut self)
pub fn assembly_completed(&mut self)
Stop this timer.
Sourcepub fn assembly_time_ms(&self) -> f64
pub fn assembly_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn velocity_resolution_started(&mut self)
pub fn velocity_resolution_started(&mut self)
Start this timer.
Sourcepub fn velocity_resolution_completed(&mut self)
pub fn velocity_resolution_completed(&mut self)
Stop this timer.
Sourcepub fn velocity_resolution_time_ms(&self) -> f64
pub fn velocity_resolution_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn velocity_update_started(&mut self)
pub fn velocity_update_started(&mut self)
Start this timer.
Sourcepub fn velocity_update_completed(&mut self)
pub fn velocity_update_completed(&mut self)
Stop this timer.
Sourcepub fn velocity_update_time_ms(&self) -> f64
pub fn velocity_update_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn broad_phase_started(&mut self)
pub fn broad_phase_started(&mut self)
Start this timer.
Sourcepub fn broad_phase_completed(&mut self)
pub fn broad_phase_completed(&mut self)
Stop this timer.
Sourcepub fn broad_phase_time_ms(&self) -> f64
pub fn broad_phase_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.
Sourceimpl Counters
impl Counters
Sourcepub fn narrow_phase_started(&mut self)
pub fn narrow_phase_started(&mut self)
Start this timer.
Sourcepub fn narrow_phase_completed(&mut self)
pub fn narrow_phase_completed(&mut self)
Stop this timer.
Sourcepub fn narrow_phase_time_ms(&self) -> f64
pub fn narrow_phase_time_ms(&self) -> f64
Gets the time elapsed for this timer, in milliseconds.