pub struct StagesCounters {
pub update_time: Timer,
pub collision_detection_time: Timer,
pub island_construction_time: Timer,
pub island_constraints_collection_time: Timer,
pub solver_time: Timer,
pub ccd_time: Timer,
pub user_changes: Timer,
}Expand description
Performance counters related to each stage of the time step.
Fields
update_time: TimerTime spent for updating the kinematic and dynamics of every body.
collision_detection_time: TimerTotal time spent for the collision detection (including both broad- and narrow- phases).
island_construction_time: TimerTime spent for the computation of collision island and body activation/deactivation (sleeping).
island_constraints_collection_time: TimerTime spent maintaining the persistent solver-facing structures (solver contact graph reconciliation for the pairs that changed this step, frontier solver-body slots, force-event pair list). O(changed pairs) — the solvers consume the persistent buckets directly, so there is no per-step constraints-collection pass anymore.
solver_time: TimerTotal time spent for the constraints resolution and position update.t
ccd_time: TimerTotal time spent for CCD and CCD resolution.
user_changes: TimerTotal time spent propagating user changes.
Implementations